==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/handlebox.cc <==
// $Id: handlebox.cc,v 1.7 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "bin.hh"

class Gtk_HandleBox : public Gtk_Bin // or Gtk_Widget etc.
{public:
	typedef Gtk_Bin Parent;
	virtual const std::string TypeName(const Widget &w) const
	{  return GtkPrefix()+"HandleBox";
	}
	virtual const std::string IncludeName(const Widget &w) const
	{  return "gtk--/handlebox.h";
	}
	Gtk_HandleBox()
	{  Writer["GtkHandleBox"]=this;
	}
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_HandleBox Gtk_HandleBox;

==> glademm_2.6.0.orig.tar.gz: glademm-2.6.0/src/writers/handlebox.cc <==
// $Id: handlebox.cc,v 1.9 2002/06/19 14:34:14 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1999-2000 Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "bin.hh"

class Gtk_HandleBox : public Gtk_Bin // or Gtk_Widget etc.
{public:
	typedef Gtk_Bin Parent;
	virtual const std::string TypeName(const Widget &w) const
	{  return GtkPrefix()+"HandleBox";
	}
	virtual const std::string IncludeName(const Widget &w) const
	{  return Configuration.GtkmmIncludePath()+"handlebox.h";
	}
	Gtk_HandleBox()
	{  Writer["GtkHandleBox"]=this;
	}
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
};

static Gtk_HandleBox Gtk_HandleBox;

void Gtk_HandleBox::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
{  Parent::Configure(w,f,instance);
   WriteEnumPropertyNS(w,f,instance, "shadow_type");
   WriteEnumPropertyNS(w,f,instance, "handle_position");
   WriteEnumPropertyNS(w,f,instance, "snap_edge");
}
